#####################################################
# UMA ESTIMATIVA DA INCERTEZA NA PREVISAO DO MODELO #
#####################################################

# estrutura dos dados
babies <- read.table("babies.txt",sep=" ",dec=".",header=T)
head(babies)
tail(babies)
str(babies)

# retirando dados faltantes
bebe <- babies[which(babies$gestation!="999"),]
bebe <- bebe[which(bebe$bwt!="999"),]
bebe <- bebe[which(bebe$parity!="9"),]
bebe <- bebe[which(bebe$age!="99"),]
bebe <- bebe[which(bebe$height!="99"),]
bebe <- bebe[which(bebe$weight!="999"),]
bebe <- bebe[which(bebe$smoke!="9"),]

# modelo linear
lmbebe <- lm(bwt~gestation, data=bebe)
summary(lmbebe)

# estimativa da incerteza na previsao do modelo
x <- seq(min(bebe$gestation)-10, max(bebe$gestation)+10, length=100)
prd <- predict(lmbebe, newdata = data.frame(gestation=x), interval='confidence')
var <- var(bebe$bwt)
n.1 <- 1/length(bebe$gestation)
x.x <- x-mean(bebe$gestation)
x.2 <- x.x^2
sum <- sum((bebe$gestation-mean(bebe$gestation))^2)
sey <- sqrt(var*(n.1+(x.2/sum)))

t1 <- qt(p=0.025,df=length(bebe$gestation-2),lower.tail = T)
t2 <- qt(p=0.025,df=length(bebe$gestation-2),lower.tail = F)
se.t <- sey*t2

# grafico para avaliar a incerteza do modelo
par(mar=c(4,5,2,2), cex.lab=1.2, cex.axis=1.2, las=1, bg = "gray70", bty="n")
plot(NA, type="n", axes=F, ann=F, xlim=range(bebe$gestation), ylim=range(bebe$bwt)) 
rect(par()$usr[1],par()$usr[3], par()$usr[2],par()$usr[4] , col="gray90")
points(bwt ~ gestation, data = bebe, pch = 19,cex= 1.2, col = rgb(1,0,0.8, 0.4))
axis(1)
axis(2)
mtext("Gestao (dias)", 1,  line=2.5, cex = 1.2)
mtext("Peso beb (onas)", 2, line=3.0, cex = 1.2, las = 0)
abline(lmbebe, lwd = 2.5, col = "purple")
polygon(c(rev(x), x), c(rev(prd[,3]), prd[,2]), col = rgb(0.6,0,0.8,0.2))

###########################################
########## GALILEU ESTAVA CERTO ###########
###########################################

# dados
init.h = c(600, 700, 800, 950, 1100, 1300, 1500)
h.d = c(253, 337, 395, 451, 495, 534, 573)

# modelos lineares
mod1 <- lm(h.d~init.h)
mod2 <- update(mod1,.~. +I(init.h^2))

# retem modelo 2
anova(mod1,mod2)

# grafico do modelo
plot(h.d~init.h)
abline(mod1)
cf.m2 <- coef(mod2)
curve(cf.m2[1]+cf.m2[2]*x+cf.m2[3]*x^2, add=T, lty=2)
summary(mod2)

# avaliando se o polinomio de 3 grau explica melhor a funcao
mod3 <- update(mod2,.~. +I(init.h^3))
anova(mod2,mod3)

# O polinomio de 3 grau explica 43 vezes mais do que o polinomio de 2 grau (p<0.007). Portanto, retemos o modelo mais complexo (3 grau)

#############################################
######### MASSA DE RECEM NASCIDOS ###########
#############################################

head(bebe)
tail(bebe)
str(bebe)

# interacoes quadruplas ou quintuplas sao dificeis de serem interpretadas biologicamente. Portanto, o modelo cheio contem no maximo interacoes triplas. 
modcheio <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke+parity:height:weight+parity:smoke:weight+age:height:smoke+age:height:weight+age:smoke:weight+height:smoke:weight,data=bebe)
summary(modcheio)
# sem height:smoke:weight
mod1 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke+parity:height:weight+parity:smoke:weight+age:height:smoke+age:height:weight+age:smoke:weight,data=bebe)
summary(mod1)
anova(modcheio,mod1) #retem mod1
# sem age:smoke:weight
mod2 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke+parity:height:weight+parity:smoke:weight+age:height:smoke+age:height:weight,data=bebe)
summary(mod2)
anova(mod2,mod1) #retem mod2
# sem age:height:weight
mod3 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke+parity:height:weight+parity:smoke:weight+age:height:smoke,data=bebe)
summary(mod3)
anova(mod2,mod3) #retem mod3
# sem age:height:smoke
mod4 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke+parity:height:weight+parity:smoke:weight,data=bebe)
summary(mod4)
anova(mod4,mod3) #retem mod4
# sem parity:smoke:weight
mod5 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke+parity:height:weight,data=bebe)
summary(mod5)
anova(mod4,mod5) #retem mod5
# sem parity:height:weight
mod6 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight+parity:height:smoke,data=bebe)
summary(mod6)
anova(mod6,mod5) #retem mod6
# sem parity:height:smoke
mod7 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke+parity:age:weight,data=bebe)
summary(mod7)
anova(mod6,mod7) #retem mod7
# sem parity:age:weight
mod8 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height+parity:age:smoke,data=bebe)
summary(mod8)
anova(mod8,mod7) #retem mod8
# sem parity:age:smoke
mod9 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight+parity:age:height,data=bebe)
summary(mod9)
anova(mod8,mod9) #retem mod9
# sem parity:age:height
mod10 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight+gestation:smoke:weight,data=bebe)
summary(mod10)
anova(mod10,mod9) #retem mod10
# sem gestation:smoke:weight
mod11 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke+gestation:height:weight,data=bebe)
summary(mod11)
anova(mod10,mod11) #retem mod11
# sem gestation:height:weight
mod12 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight+gestation:height:smoke,data=bebe)
summary(mod12)
anova(mod12,mod11) #retem mod12
# sem gestation:height:smoke
mod13 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke+gestation:age:weight,data=bebe)
summary(mod13)
anova(mod12,mod13) #retem mod13
# sem gestation:age:weight
mod14 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height+gestation:age:smoke,data=bebe)
summary(mod14)
anova(mod14,mod13) #retem mod14
# sem gestation:age:smoke
mod15 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight+gestation:age:height,data=bebe)
summary(mod15)
anova(mod14,mod15) #retem mod15
# sem gestation:age:height
mod16 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke+gestation:parity:weight,data=bebe)
summary(mod16)
anova(mod16,mod15) #retem mod16
# sem gestation:parity:weight
mod17 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height+gestation:parity:smoke,data=bebe)
summary(mod17)
anova(mod16,mod17) #retem mod17
# sem gestation:parity:smoke
mod18 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age+gestation:parity:height,data=bebe)
summary(mod18)
anova(mod18,mod17) #retem mod18
# sem gestation:parity:height
mod19 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight+gestation:parity:age,data=bebe)
summary(mod19)
anova(mod18,mod19) #retem mod19
# sem gestation:parity:age
mod20 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight+smoke:weight,data=bebe)
summary(mod20)
anova(mod20,mod19) #retem mod20
# sem smoke:weight
mod21 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke+height:weight,data=bebe)
summary(mod21)
anova(mod20,mod21) #retem mod21
# sem height:weight
mod22 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight+height:smoke,data=bebe)
summary(mod22)
anova(mod22,mod21) #retem mod22
# sem height:smoke
mod23 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke+age:weight,data=bebe)
summary(mod23)
anova(mod22,mod23) #retem mod23
# sem age:weight
mod24 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height+age:smoke,data=bebe)
summary(mod24)
anova(mod24,mod23) #retem mod24
# sem age:smoke
mod25 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight+age:height,data=bebe)
summary(mod25)
anova(mod24,mod25) #retem mod25
# sem age:height
mod26 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke+parity:weight,data=bebe)
summary(mod26)
anova(mod26,mod25) #retem mod26
# sem parity:weight
mod27 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height+parity:smoke,data=bebe)
summary(mod27)
anova(mod26,mod27) #retem mod27
# sem parity:smoke
mod28 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age+parity:height,data=bebe)
summary(mod28)
anova(mod28,mod27) #retem mod28
# sem parity:height
mod29 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight+parity:age,data=bebe)
summary(mod28)
anova(mod28,mod29) #retem mod29
# sem parity:age
mod30 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke+gestation:weight,data=bebe)
summary(mod30)
anova(mod30,mod29) #retem mod30
# sem gestation:weight
mod31 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height+gestation:smoke,data=bebe)
summary(mod31)
anova(mod30,mod31) #retem mod31
# sem gestation:smoke
mod32 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:height,data=bebe)
summary(mod32)
anova(mod32,mod31) #retem mod31
# sem gestation:height
mod33 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:smoke,data=bebe)
summary(mod33)
anova(mod33,mod31) #retem mod33
# sem gestation:age
mod34 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:smoke,data=bebe)
summary(mod34)
anova(mod33,mod34) #retem mod33
# sem gestation:parity
mod35 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:age+gestation:smoke,data=bebe)
summary(mod35)
anova(mod33,mod35) #retem mod33
# sem weight
mod36 <- lm(bwt~gestation+parity+age+height+smoke+gestation:parity+gestation:age+gestation:smoke,data=bebe)
summary(mod36)
anova(mod33,mod36) #retem mod33
# sem height
mod37 <- lm(bwt~gestation+parity+age+smoke+weight+gestation:parity+gestation:age+gestation:smoke,data=bebe)
summary(mod37)
anova(mod33,mod37) #retem mod33

### modelo minimo adequado: mod33 ###
# mod33 <- lm(bwt~gestation+parity+age+height+smoke+weight+gestation:parity+gestation:age+gestation:smoke,data=bebe)