# Crie uma funo para sada grfica de anlises exploratrias de duas variveis. Essa sada pode ter
# por exemplo boxplot, histograma, qq norm e y por x. A funo deve permitir a entrada de dois objetos
# vetores de mesmo tamanho (x e y). Caso os valores de x e y forem desenhados em um mesmo grfico,
# defina cores diferentes. As legendas devem ser em portugus e a sada (return) deve apresentar o
# sumrio das duas variveis e o coeficiente de correlao.

exploraData <- function(x, y, cor)
{
  if(sum(is.na(x) == TRUE) > 0 | sum(is.na(y) == TRUE) > 0)
  {
    nasx <- length(x[is.na(x) == TRUE]) 
    nasy <- length(y[is.na(y) == TRUE]) 
    stop("Seus dados contm ", "x:", nasx, " e ", "y:", nasy, " NAs\n",
         "precisa tirar eles antes de rodas a funo")
  }
  
  x11()
  par(tcl = 0.3, bty = "l", family = "serif", cex.axis = 1.2, cex.lab = 1.5,
      mar = c(5.1, 4.5, 4.1, 2.1))
  layout(matrix(c(1,2,2,3,4,5), nrow = 2, ncol = 3, byrow = TRUE), widths = c(1.8,1.2,1.2))
  
  boxplot(x, y, xlab = "", ylab = "", col = c(rgb(0.7,0.5,0.5,0.7), rgb(0.2,0.3,0.2,0.7)),
          axes = FALSE)
  axis(1, at = c(1, 2), labels = FALSE)
  axis(2, las = 2)
  mtext(text = c("Varivel X", "Varivel Y"), side = 1, line = 1, at = c(1, 2))
  
  hist(x, col = rgb(0.7,0.5,0.5,0.7), xlim = c(-1, 8), ylim = c(0, 40), main = "",
       xlab = "", ylab = "Frequncias")
  hist(y, col = rgb(0.2,0.3,0.2,0.7), add = TRUE, breaks = 7)
  
  plot(x, y, xlab = "Varivel X", ylab = "Varivel Y", ylim = c(0, 3.5),
       col = c(rgb(0.7,0.5,0.5,0.7), rgb(0.2,0.3,0.2,0.7)), pch = 19, axes = FALSE)
  axis(1, xlim = c(1,8))
  axis(2, las = 2)
  
  qqnorm(x, main = "", col = rgb(0.7,0.5,0.5,0.7), pch = 19, cex = 1.2,
         xlab = "", ylab = "")
  qqline(x, distribution = qnorm, col = rgb(0.7,0.5,0.5,0.7), lwd = 3)
  
  mtext(text = c("Quanties tericos", "Quanties da amostra"), side = c(1,2),
        line = 2.5, at = c(5, 4.5))
  
  qqnorm(y, main = "", col = rgb(0.2,0.3,0.2,0.7), pch = 19, cex = 1.2,
         xlab = "", ylab = "")
  qqline(y, distribution = qnorm, col = rgb(0.2,0.3,0.2,0.7), lwd = 3)

  cortest <- rep(NA, 3)
  p.val <- rep(NA, 3)
  for(i in 1:3)
  {
  methods <- c("pearson", "kendall", "spearman")
  test <- cor.test(x, y, method = methods[i])
  cortest[i] <- test$estimate
  p.val[i] <- test$p.value
  }

cor <- match.arg(cor, choices = c("pearson", "kendall", "spearman"))
if(cor == "pearson") cat("cor:", cortest[1], " p-value =", p.val[1], "\n")
if(cor == "kendall") cat("tau:", cortest[2], " p-value =", p.val[2], "\n")
if(cor == "spearman") cat("rho:", cortest[3], " p-value =", p.val[3], "\n")

return(list(summary(x), summary(y)))

} 

## Testando a funo
a <- rnorm(n = 100, mean = 5)
b <- rnorm(n = 100, mean = 2, sd = 0.5)
c <- c(rnorm(n = 97, mean = 5), rep(NA,3))

exploraData(a,b)
exploraData(c, b, cor = "pearson")
exploraData(a, b, cor = "ken")